@@ -18,21 +18,21 @@ def _prepare_df(data):
                .rename(columns={'index': 'ds', 'Close': 'y'}) \
                .loc[:, ['ds', 'y']]
 
-def train_model():
+def train_model(filepath='models/btc_model.pkl'):
     df = _prepare_df(_get_history())
     model = prophet.Prophet()
     model.fit(df)
 
-    with open('models/btc_model.pkl', 'wb') as file:
+    with open(filepath, 'wb') as file:
         pickle.dump(model, file)
 
-def read_model():
-    return pickle.load(open('models/btc_model.pkl', 'rb'))
+def read_model(filepath='btc_model.pkl'):
+    return pickle.load(open(filepath, 'rb'))
 
-def get_preidction(n_steps):
+def get_preidction(n_steps, plot_filepath='static/plot.png'):
     model = read_model()
     forecast = model.predict(model.make_future_dataframe(periods=n_steps))
-    model.plot(forecast.iloc[-72:]).savefig('static/plot.png')
+    model.plot(forecast.iloc[-144:]).savefig(plot_filepath)
 
     return forecast.iloc[-n_steps:][['ds', 'yhat', 'yhat_lower', 'yhat_upper']]
 
